parse_html: Convert html to plain text

Description Usage Arguments Value

View source: R/parse_html.R

Description

Removes html from a downloaded article by calling the htm2txt package.

Usage

1
parse_html(html = NULL, url = NULL)

Arguments

html

A large string of length 1 containing the html for a journal article

Value

A character vector containing the plain text version of the input html document with paragraphs in separate lines.


ESHackathon/doi2txt documentation built on Dec. 17, 2021, 5:39 p.m.