Description Usage Arguments Value
Removes html from a downloaded article by calling the htm2txt package.
1 | parse_html(html = NULL, url = NULL)
|
html |
A large string of length 1 containing the html for a journal article |
A character vector containing the plain text version of the input html document with paragraphs in separate lines.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.